@@ -54,13 +54,17 @@ sub go
     $opts->{'skip-tests-for'} = [];
   }
   $opts->{'skip-tests-for'}
-      = { map { $_ => 1 } @{ $opts->{'skip-tests-for'} } };
+    = { map { $_ => 1 } @{ $opts->{'skip-tests-for'} } };
+
+  my $unsafe_inc
+    = exists $ENV{PERL_USE_UNSAFE_INC} ? $ENV{PERL_USE_UNSAFE_INC} : 1;
 
   # trick AutoInstall
   local $ENV{PERL5_CPAN_IS_RUNNING}     = $$;
   local $ENV{PERL5_CPANPLUS_IS_RUNNING} = $$;
 
   local $ENV{PERL_MM_USE_DEFAULT} = 1;
+  local $ENV{PERL_USE_UNSAFE_INC} = $unsafe_inc;
 
   local $ENV{PERL_MM_OPT} = "INSTALL_BASE=$dest_dir";
   local $ENV{PERL_MB_OPT} = "--install_base $dest_dir";
@@ -301,14 +305,9 @@ sub _install
   local $ENV{PERL_MM_USE_DEFAULT}    = 0;
   local $ENV{NONINTERACTIVE_TESTING} = 0;
 
-  state $make;
+  my $make = $Config{make};
   my $opts = $cache->{opts};
 
-  if ( !defined $make )
-  {
-    $make = $Config{make};
-  }
-
   my $skip_tests = $cache->{opts}->{'skip-tests'};
   if ( !$skip_tests )
   {
